# Change Log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## [Unreleased][unreleased]

## [0.3.1][0.3.1] - 2019-01-01
### Changed
* created new wheel for pypi

## [0.3.0][0.3.0] - 2019-01-01
### Changed
* set minimum requirement for to `passlib>=1.7.0`
    * changed internal password hashing call

## [0.2.5][0.2.5] - 2015-10-05
### Removed
* class `Match` from module `regrex`

### Added
* regular expression generator
* authentication helpers

## [0.2.4][0.2.4] - 2015-09-11
### Changed
* removed numpy as dependency
* created custom median function in `tocoli.ratio`

## [0.2.3][0.2.3] - 2015-09-10

## [0.2.2][0.2.2] - 2015-09-10

## [0.2.1][0.2.1] - 2015-09-10

## [0.2.0][0.2.0] - 2015-09-09
### Changed
* The former ``dsl`` module is now an own subpackage.
* The `keys` parameter notation for sorting functions changed.
* There are new `flags` paramter options for mapping functions.

## [0.1.0][0.1.0] - 2015-09-07
### Added
new modules:
    cmp - compare utilities
    dsl - python like it should be.
    enc - encoding
    filter - filter functions
    fn - common lambda functions
    join - join functions
    map - recursive mapping
    ratio - ratio functions
    regex - regular expression utilities
    sort - sort functions
    spell - spelling utilities
    string - string functions
    test - testing and benchmarking
    type - type conversion utilities

[unreleased]: https://github.com/tocoli/tocolib/tree/master
[0.3.1]: https://github.com/tocoli/tocolib/tree/0.3.0
[0.3.0]: https://github.com/tocoli/tocolib/tree/0.3.0
[0.2.5]: https://github.com/tocoli/tocolib/tree/0.2.5
[0.2.4]: https://github.com/tocoli/tocolib/tree/0.2.4
[0.2.3]: https://github.com/tocoli/tocolib/tree/0.2.3
[0.2.2]: https://github.com/tocoli/tocolib/tree/0.2.2
[0.2.1]: https://github.com/tocoli/tocolib/tree/0.2.1
[0.2.0]: https://github.com/tocoli/tocolib/tree/0.2.0
[0.1.0]: https://github.com/tocoli/tocolib/tree/0.1.0
